=============================
django-paginated-urls
=============================

.. image:: https://badge.fury.io/py/django-paginated-urls.png
    :target: https://badge.fury.io/py/django-paginated-urls

.. image:: https://travis-ci.org/cyrildoussin/django-paginated-urls.png?branch=master
    :target: https://travis-ci.org/cyrildoussin/django-paginated-urls

Helpers for returning users to the correct page of a view using pagination.

Note: this is work in-progress that hasn't been battle-tested (yet). Use at your own risk.

Documentation
-------------

The full documentation is at https://django-paginated-urls.readthedocs.org.

Quickstart
----------

Install django-paginated-urls::

    pip install django-paginated-urls

Then use it in a project::

    import paginated_urls

Features
--------

* TODO

Cookiecutter Tools Used in Making This Package
----------------------------------------------

*  cookiecutter
*  cookiecutter-djangopackage
